@@ -5,24 +5,11 @@ source files using the Abstract Syntax Tree (AST).
 """
 
 import ast
-from typing import Any, Callable
+from typing import Any
 
+from coding_open_agent_tools._decorators import adk_tool, strands_tool
 from coding_open_agent_tools.exceptions import CodeAnalysisError
-
-try:
-    from strands import tool as strands_tool
-except ImportError:
-    # Create a no-op decorator if strands is not installed
-    def strands_tool(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[no-redef]
-        return func
-
-
-try:
-    from google.adk.tools import tool as adk_tool
-except ImportError:
-    # Create a no-op decorator if google-adk is not installed
-    def adk_tool(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[no-redef]
-        return func
+from coding_open_agent_tools.types import STDLIB_MODULES
 
 
 @adk_tool
@@ -331,214 +318,6 @@ def extract_imports(file_path: str) -> dict[str, list[str]]:
     except Exception as e:
         raise CodeAnalysisError(f"Error parsing {file_path}: {str(e)}")
 
-    # Standard library modules (Python 3.9+)
-    stdlib_modules = {
-        "abc",
-        "aifc",
-        "argparse",
-        "array",
-        "ast",
-        "asynchat",
-        "asyncio",
-        "asyncore",
-        "atexit",
-        "audioop",
-        "base64",
-        "bdb",
-        "binascii",
-        "binhex",
-        "bisect",
-        "builtins",
-        "bz2",
-        "calendar",
-        "cgi",
-        "cgitb",
-        "chunk",
-        "cmath",
-        "cmd",
-        "code",
-        "codecs",
-        "codeop",
-        "collections",
-        "colorsys",
-        "compileall",
-        "concurrent",
-        "configparser",
-        "contextlib",
-        "contextvars",
-        "copy",
-        "copyreg",
-        "crypt",
-        "csv",
-        "ctypes",
-        "curses",
-        "dataclasses",
-        "datetime",
-        "dbm",
-        "decimal",
-        "difflib",
-        "dis",
-        "distutils",
-        "doctest",
-        "email",
-        "encodings",
-        "enum",
-        "errno",
-        "faulthandler",
-        "fcntl",
-        "filecmp",
-        "fileinput",
-        "fnmatch",
-        "formatter",
-        "fractions",
-        "ftplib",
-        "functools",
-        "gc",
-        "getopt",
-        "getpass",
-        "gettext",
-        "glob",
-        "graphlib",
-        "grp",
-        "gzip",
-        "hashlib",
-        "heapq",
-        "hmac",
-        "html",
-        "http",
-        "imaplib",
-        "imghdr",
-        "imp",
-        "importlib",
-        "inspect",
-        "io",
-        "ipaddress",
-        "itertools",
-        "json",
-        "keyword",
-        "lib2to3",
-        "linecache",
-        "locale",
-        "logging",
-        "lzma",
-        "mailbox",
-        "mailcap",
-        "marshal",
-        "math",
-        "mimetypes",
-        "mmap",
-        "modulefinder",
-        "multiprocessing",
-        "netrc",
-        "nis",
-        "nntplib",
-        "numbers",
-        "operator",
-        "optparse",
-        "os",
-        "ossaudiodev",
-        "parser",
-        "pathlib",
-        "pdb",
-        "pickle",
-        "pickletools",
-        "pipes",
-        "pkgutil",
-        "platform",
-        "plistlib",
-        "poplib",
-        "posix",
-        "posixpath",
-        "pprint",
-        "profile",
-        "pstats",
-        "pty",
-        "pwd",
-        "py_compile",
-        "pyclbr",
-        "pydoc",
-        "queue",
-        "quopri",
-        "random",
-        "re",
-        "readline",
-        "reprlib",
-        "resource",
-        "rlcompleter",
-        "runpy",
-        "sched",
-        "secrets",
-        "select",
-        "selectors",
-        "shelve",
-        "shlex",
-        "shutil",
-        "signal",
-        "site",
-        "smtpd",
-        "smtplib",
-        "sndhdr",
-        "socket",
-        "socketserver",
-        "spwd",
-        "sqlite3",
-        "ssl",
-        "stat",
-        "statistics",
-        "string",
-        "stringprep",
-        "struct",
-        "subprocess",
-        "sunau",
-        "symbol",
-        "symtable",
-        "sys",
-        "sysconfig",
-        "syslog",
-        "tabnanny",
-        "tarfile",
-        "telnetlib",
-        "tempfile",
-        "termios",
-        "test",
-        "textwrap",
-        "threading",
-        "time",
-        "timeit",
-        "tkinter",
-        "token",
-        "tokenize",
-        "trace",
-        "traceback",
-        "tracemalloc",
-        "tty",
-        "turtle",
-        "turtledemo",
-        "types",
-        "typing",
-        "unicodedata",
-        "unittest",
-        "urllib",
-        "uu",
-        "uuid",
-        "venv",
-        "warnings",
-        "wave",
-        "weakref",
-        "webbrowser",
-        "winreg",
-        "winsound",
-        "wsgiref",
-        "xdrlib",
-        "xml",
-        "xmlrpc",
-        "zipapp",
-        "zipfile",
-        "zipimport",
-        "zlib",
-        "zoneinfo",
-    }
-
     all_imports = []
     stdlib_imports = []
     third_party_imports = []
@@ -550,7 +329,7 @@ def extract_imports(file_path: str) -> dict[str, list[str]]:
                 module_name = alias.name.split(".")[0]
                 all_imports.append(alias.name)
 
-                if module_name in stdlib_modules:
+                if module_name in STDLIB_MODULES:
                     stdlib_imports.append(alias.name)
                 else:
                     third_party_imports.append(alias.name)
@@ -564,7 +343,7 @@ def extract_imports(file_path: str) -> dict[str, list[str]]:
                 module_name = node.module.split(".")[0]
                 all_imports.append(node.module)
 
-                if module_name in stdlib_modules:
+                if module_name in STDLIB_MODULES:
                     stdlib_imports.append(node.module)
                 else:
                     third_party_imports.append(node.module)
