@@ -1,11 +1,11 @@
-from typing import Any, Callable
-
 """Secret pattern definitions for code scanning.
 
 This module contains regex patterns for detecting various types of secrets
 and credentials in source code.
 """
 
+from coding_open_agent_tools._decorators import adk_tool, strands_tool
+
 # Secret pattern definitions with severity levels
 SECRET_PATTERNS: list[dict[str, str]] = [
     # AWS Keys
@@ -178,21 +178,6 @@ SECRET_PATTERNS: list[dict[str, str]] = [
     },
 ]
 
-try:
-    from strands import tool as strands_tool
-except ImportError:
-    # Create a no-op decorator if strands is not installed
-    def strands_tool(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[no-redef]
-        return func
-
-
-try:
-    from google.adk.tools import tool as adk_tool
-except ImportError:
-    # Create a no-op decorator if google-adk is not installed
-    def adk_tool(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[no-redef]
-        return func
-
 
 @adk_tool
 @strands_tool
